@@ -243,33 +243,57 @@ Projection.prototype.transform = function(entity, k, op, preview, flags, rec) {
         this.preTransform(entity);
     }
 
+    var explode = false;
+
     if (this.retainTexts && isTextBasedEntity(entity)) {
-        // don't explode text, only project position:
-        var e = entity.clone();
-        e.setSelected(false);
-        var p = e.getAlignmentPoint();
-        //qDebug("p before:", p);
-        //qDebug("ap:", e.getAlignmentPoint());
-        this.project(p);
-        //qDebug("p after:", p);
-        //e.setPosition(p);
-        e.setAlignmentPoint(p);
-        flags = flags | RAddObjectsOperation.UseAttributes;
-        op.addObject(e, flags);
-        return;
+        if (isAttributeEntity(entity)) {
+            explode = true;
+        }
+        else {
+            // don't explode text, only project position:
+            var e = entity.clone();
+            e.setSelected(false);
+            var p = e.getAlignmentPoint();
+            var ph = p.operator_add(new RVector(0,e.getTextHeight()));
+            //qDebug("p before:", p);
+            //qDebug("ph before:", ph);
+            //qDebug("ap:", e.getAlignmentPoint());
+            this.project(p);
+            this.project(ph);
+
+            // project height:
+            //qDebug("p after:", p);
+            //qDebug("ph after:", ph);
+            //e.setPosition(p);
+
+            e.setAlignmentPoint(p);
+            e.setTextHeight(p.getDistanceTo(ph));
+
+            flags = flags | RAddObjectsOperation.UseAttributes;
+            op.addObject(e, flags);
+            return;
+        }
     }
 
     // explode block reference to keep attributes (colors, etc.):
     if (isBlockReferenceEntity(entity)) {
-        var explodedEntities = Explode.explodeEntity(entity);
-        for (i=0; i<explodedEntities.length; i++) {
-            var explodedEntity = explodedEntities[i];
+        explode = true;
+    }
 
-            if (isEntity(explodedEntity)) {
-                this.transform(explodedEntity, k, op, preview, flags, true);
-            }
-            else {
-                qWarning("shape in exploded block");
+    if (explode) {
+        // explode attributes to texts
+        // explode block reference
+        var explodedEntities = Explode.explodeEntity(entity);
+        if (!isNull(explodedEntities)) {
+            for (i=0; i<explodedEntities.length; i++) {
+                var explodedEntity = explodedEntities[i];
+
+                if (isEntity(explodedEntity)) {
+                    this.transform(explodedEntity, k, op, preview, flags, true);
+                }
+                else {
+                    qWarning("shape in exploded block");
+                }
             }
         }
         return;
@@ -494,12 +518,20 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
 
     if (isArcShape(shape)) {
         var self=this;
+        // TODO: use RShape::transformArc
+        // make RShapeTransformation scriptable
+        // override RShapeTransformation::transform
         var ellipse = ShapeAlgorithms.transformArc(shape,
             function(p) {
                 self.project(p);
             }
         );
-        return [ ellipse ];
+        if (ellipse.isValid()) {
+            return [ ellipse ];
+        }
+        else {
+            return [];
+        }
     }
 
     if (isCircleShape(shape)) {
@@ -525,6 +557,7 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
             }
         }
 
+        // create polyline from ellipse:
         var ple = ShapeAlgorithms.approximateEllipse(shape, 16);
         return this.projectShape(ple, preview, trim);
     }
@@ -611,7 +644,10 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
                     }
 
                     if (gotEllipse) {
-                        ret.push(seg);
+                        if (seg.isValid()) {
+                            ret.push(seg);
+                        }
+
                         pl = new RPolyline();
                     }
                     else if (gotGap){
@@ -628,6 +664,40 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
             ret.push(pl);
         }
 
+        // set global width if polyline has uniform global semgent width:
+        var gotGlobalWidth = false;
+        var startWidths = shape.getStartWidths();
+        var endWidths = shape.getEndWidths();
+        if (startWidths.length>0 && endWidths.length>0) {
+            if (startWidths[0]>RS.PointTolerance) {
+                startWidths.sortNumerical();
+                endWidths.sortNumerical();
+                if (RMath.fuzzyCompare(startWidths[0], startWidths[startWidths.length-1]) &&
+                    RMath.fuzzyCompare(endWidths[0], endWidths[endWidths.length-1]) &&
+                    RMath.fuzzyCompare(startWidths[0], endWidths[0])) {
+
+                    // got global polyline width:
+                    gotGlobalWidth = true;
+                    for (i=0; i<ret.length; i++) {
+                        if (isPolylineShape(ret[i])) {
+                            ret[i].setGlobalWidth(startWidths[0]);
+                        }
+                    }
+                }
+            }
+        }
+
+        // set pl segment widths if there's no segmentation and the number of segments match:
+        if (ret.length===1 && isPolylineShape(ret[0])) {
+            if (!gotGlobalWidth && !this.segmentation && shape.countSegments()===ret[0].countSegments()) {
+                for (i=0; i<shape.countVertices(); i++) {
+                    ret[0].setStartWidthAt(i, shape.getStartWidthAt(i));
+                    ret[0].setEndWidthAt(i, shape.getEndWidthAt(i));
+                }
+            }
+        }
+
+
         return ret;
     }
 
