@@ -321,7 +321,7 @@ ShapeAlgorithms.getIntersectingShapes = function(doc, entityId, shape, extend) {
 
     // find other shapes that potentially intersect with the chosen entity:
     var ret = [];
-    // allow for error: especialy for ellipse segments bordering to tangential lines this is needed:
+    // allow for error: especially for ellipse segments bordering to tangential lines this is needed:
     var otherEntityIds;
 
     if (extend===true) {
@@ -341,6 +341,10 @@ ShapeAlgorithms.getIntersectingShapes = function(doc, entityId, shape, extend) {
     for (var i=0; i<otherEntityIds.length; i++) {
         var otherEntity = doc.queryEntityDirect(otherEntityIds[i]);
 
+        if (isTextBasedEntity(otherEntity)) {
+            continue;
+        }
+
         // ignore intersection points of same entity
         // self intersection points are handled elsewhere
         var same = otherEntityIds[i]===entityId;
@@ -640,6 +644,12 @@ ShapeAlgorithms.autoSplitManual = function(shape, cutDist1, cutDist2, cutPos1, c
 
     // arcs:
     else if (isArcShape(shape)) {
+        if (cutDist1 > cutDist2) {
+            var dummy = cutDist1;
+            cutDist1 = cutDist2;
+            cutDist2 = dummy;
+        }
+
         rest1 = shape.clone();
         rest2 = shape.clone();
 
@@ -657,7 +667,14 @@ ShapeAlgorithms.autoSplitManual = function(shape, cutDist1, cutDist2, cutPos1, c
         if (!extend) {
             var angleLength1 = rest1.getAngleLength(true);
             var angleLength2 = rest2.getAngleLength(true);
-            if (angleLength1+angleLength2 > shape.getAngleLength()) {
+
+            // rest1 is the same as the segment:
+            var same1 = RMath.fuzzyAngleCompare(rest1.getStartAngle(), segment.getStartAngle()) &&
+                    RMath.fuzzyAngleCompare(rest1.getEndAngle(), segment.getEndAngle()) &&
+                    rest1.isReversed()===segment.isReversed();
+
+            // catch common errors:
+            if (angleLength1+angleLength2 > shape.getAngleLength() || same1) {
                 rest1.trimEndPoint(cutDist2);
                 rest2.trimStartPoint(cutDist1);
 
@@ -798,6 +815,7 @@ ShapeAlgorithms.autoSplitManual = function(shape, cutDist1, cutDist2, cutPos1, c
 
     // polyline:
     else if (isPolylineShape(shape)) {
+
         var closed = shape.isGeometricallyClosed();
         if (closed) {
             shape.relocateStartPoint(cutDist1);
@@ -819,32 +837,21 @@ ShapeAlgorithms.autoSplitManual = function(shape, cutDist1, cutDist2, cutPos1, c
             rest2.trimStartPoint(cutDist2);
         }
         else {
-//            var l1 = shape.getLengthTo(cutDist1);
-//            if (l1<RS.PointTolerance && cutDist1.isEnd===true) {
-//                l1 = shape.getLength();
-//            }
-//            var l2 = shape.getLengthTo(cutDist2);
-//            if (l2<RS.PointTolerance && cutDist2.isEnd===true) {
-//                l2 = shape.getLength();
-//            }
+            // make sure point 1 is closer to the start of the polyline:
+            if (cutDist1 > cutDist2) {
+                var dummy = cutDist1;
+                cutDist1 = cutDist2;
+                cutDist2 = dummy;
+            }
 
-            // TODO: use real click point (position)
-//            if (l1 > l2) {
-//                rest1.trimEndPoint(cutDist2, cutDist2);
-//                segment.trimStartPoint(cutDist2, cutDist2);
-//                segment.trimEndPoint(cutDist1, cutDist1);
-//                rest2.trimStartPoint(cutDist1, cutDist1);
-//            }
-//            else {
-                rest1.trimEndPoint(cutDist1);
+            rest1.trimEndPoint(cutDist1);
 
-                var l1 = segment.getLength();
-                segment.trimStartPoint(cutDist1);
-                var l2 = segment.getLength();
-                segment.trimEndPoint(cutDist2 - (l1-l2));
+            var l1 = segment.getLength();
+            segment.trimStartPoint(cutDist1);
+            var l2 = segment.getLength();
+            segment.trimEndPoint(cutDist2 - (l1-l2));
 
-                rest2.trimStartPoint(cutDist2);
-//            }
+            rest2.trimStartPoint(cutDist2);
         }
 
         if (!isNull(segment)) {
@@ -1830,17 +1837,20 @@ ShapeAlgorithms.transformArc = function(arc, fun) {
         r2 = new RVector(0, arc.getRadius());
     }
 
+    // get vertices at extremities:
     var v1 = arc.getCenter().operator_add(r1).operator_add(r2);
     var v2 = arc.getCenter().operator_add(r1).operator_subtract(r2);
     var v3 = arc.getCenter().operator_subtract(r1).operator_subtract(r2);
     var v4 = arc.getCenter().operator_subtract(r1).operator_add(r2);
 
+    // project those vertices:
     fun(v1);
     fun(v2);
     fun(v3);
     fun(v4);
 
     //var ret = [];
+    // inscribe ellipse into vertices:
     var ellipse = ShapeAlgorithms.createEllipseInscribedFromVertices(v1, v2, v3, v4);
     //ret.push(ellipse.copy());
 
