@@ -72,20 +72,34 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
         parent = RMainWindowQt.getMainWindow();
     }
 
-    var fileInfo = new QFileInfo(uiFile);
-    if (!fileInfo.exists() && !fileInfo.isAbsolute()) {
-        if (basePath.length>0) {
-            uiFile = basePath + "/" + uiFile;
+    var candidates;
+    if (!new QFileInfo(uiFile).isAbsolute()) {
+        candidates = [
+            uiFile,
+            basePath + "/" + uiFile
+        ];
+        if (!uiFile.startsWith(":")) {
+            candidates.push(":" + uiFile);
         }
+        if (!basePath.startsWith(":")) {
+            candidates.push(":" + basePath + "/" + uiFile);
+        }
+    }
+    else {
+        candidates = [
+            uiFile
+        ];
+    }
 
-        fileInfo = new QFileInfo(uiFile);
-        if (!fileInfo.exists()) {
-            uiFile = ":" + uiFile;
-            fileInfo = new QFileInfo(uiFile);
+    for (var i=0; i<candidates.length; i++) {
+        var candidate = candidates[i];
+        var fileInfo = new QFileInfo(candidate);
+        if (fileInfo.exists()) {
+            uiFile = candidate;
         }
     }
 
-    //fileInfo = new QFileInfo(uiFile);
+    var fileInfo = new QFileInfo(uiFile);
     if (!fileInfo.exists()) {
         qWarning("WidgetFactory: File %1 does not exist".arg(uiFile));
         return undefined;
@@ -104,7 +118,7 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
 
     var formWidget = loader.load(buf, parent);
     buf.close();
-    loader.destroy();
+    destr(loader);
 
     if (isNull(formWidget)) {
         qDebug("WidgetFactory.createWidget: widget is NULL");
@@ -131,7 +145,7 @@ WidgetFactory.createDialog = function(basePath, uiFile, parent) {
     dialog.setWindowFlags(flags);
 
     // a global function might be defined to do additional
-    // initilization for all dialogs (e.g. for testing purposes):
+    // initialization for all dialogs (e.g. for testing purposes):
     if (typeof(initDialog)!=="undefined") {
         for (var i=0; i<initDialog.length; i++) {
             initDialog[i](dialog);
@@ -184,6 +198,31 @@ WidgetFactory.getKeyString = function(group, obj) {
     }
 };
 
+WidgetFactory.saveSize = function(widget) {
+    if (!widget) {
+        return;
+    }
+    var name = widget.objectName;
+    if (name.length===0) {
+        return;
+    }
+    RSettings.setValue(name + "/Width", widget.width);
+    RSettings.setValue(name + "/Height", widget.height);
+};
+
+WidgetFactory.restoreSize = function(widget) {
+    if (!widget) {
+        return;
+    }
+    var name = widget.objectName;
+    if (name.length===0) {
+        return;
+    }
+    var w = RSettings.getIntValue(name + "/Width", widget.width);
+    var h = RSettings.getIntValue(name + "/Height", widget.height);
+    widget.resize(w, h);
+};
+
 /**
  * Saves the current state of the given \c widget and all its child widgets.
  *
@@ -306,6 +345,9 @@ WidgetFactory.saveState = function(widget, group, document, map) {
         else if (isOfType(c, QSpinBox) || isOfType(c, QDoubleSpinBox)) {
             value = c.value;
         }
+        else if (isOfType(c, QSlider)) {
+            value = c.value;
+        }
         else if (isOfType(c, QListWidget)) {
             var items = [];
             if (c.count != 0) {
@@ -547,7 +589,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 c.setPlainText(value);
             }
             continue;
-        }        
+        }
         if (isOfType(c, RMathLineEdit)) {
             WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
             c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
@@ -823,6 +865,24 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             continue;
         }
+        if (isOfType(c, QSlider)) {
+            WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
+            c["valueChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+
+            if (isNull(c.defaultValue)) {
+                c.defaultValue = c.value;
+                if (signalReceiver!=undefined) {
+                    f = signalReceiver["slot" + c.objectName + "Changed"];
+                    if (isFunction(f)) {
+                        f.call(signalReceiver, c.value);
+                    }
+                }
+            }
+            if (!isNull(value)) {
+                c.value = value;
+            }
+            continue;
+        }
         if (isOfType(c, QListWidget)) {
             // the SaveContents property is set to false
             // if the list contents should not be saved to
@@ -984,7 +1044,7 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
 
     // move child widgets of UI file based widget directly to
     // options toolbar. rendering of tool buttons greatly depends
-    // on this (especially on Mac OS X):
+    // on this (especially on macOS):
     var children = sourceWidget.children();
     for(var i=0;i<children.length;++i) {
         var w=children[i];
@@ -1043,10 +1103,6 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
 };
 
 WidgetFactory.adjustIcons = function(includeBasePath, widget) {
-    if (!RSettings.hasDarkGuiBackground()) {
-        return;
-    }
-
     if (!isFunction(widget.children)) {
         return;
     }
@@ -1055,17 +1111,16 @@ WidgetFactory.adjustIcons = function(includeBasePath, widget) {
     for(var i=0;i<children.length;++i) {
         var w=children[i];
 
-        // adjust icon for dark themes:
+        // adjust icon for theme / dark mode:
         if (isOfType(w, QToolButton)) {
-            var iconFile = includeBasePath + "/" + w.objectName + "-inverse.svg";
-            if (new QFileInfo(iconFile).exists()) {
+            var iconFile = autoIconPath(includeBasePath + "/" + w.objectName + ".svg");
+            if (!isNull(iconFile)) {
                 w.icon = new QIcon(iconFile);
             }
         }
         else {
             WidgetFactory.adjustIcons(includeBasePath, w);
         }
-
     }
 };
 
@@ -1089,24 +1144,38 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
 
         // TODO: split into submenus (math, greek, ...):
         var symbols = [
-                ["\u00F8", qsTr("Diameter")],
-                ["\u2312", qsTr("Arc")],
-                ["\u00B0", qsTr("Degree")],
-                ["\u00B1", qsTr("Plus/Minus")],
-                ["\u2248", qsTr("Almost equal to")],
-                ["\u2243", qsTr("Asymptotically equal to")],
-                ["\u03C0", qsTr("Pi")],
-                ["\u221A", qsTr("Square root")],
-                ["\u03A6", qsTr("Phi")],
-                ["\u0278", qsTr("phi")],
-                ["\u03C6", qsTr("Alt phi")],
-                ["\u2126", qsTr("Ohm")],
-                ["\u03C9", qsTr("omega")],
-                ["\u00D7", qsTr("Multiplication")],
-                ["\u00F7", qsTr("Division")],
-                ["\u25FB", qsTr("Square")],
-                ["\u0394", qsTr("Delta")],
-                ["\\SA^B;", qsTr("Stacked text"), "\\\\SA^B;"]
+                    [0x00B0, qsTr("Degrees")],
+                    [0x00B1, qsTr("Plus/Minus")],
+                    [0x00F8, qsTr("Diameter")],
+                    [0x00F7, qsTr("Division")],
+                    [0x2248, qsTr("Almost Equal")],
+                    [0x2220, qsTr("Angle")],
+                    [0x2312, qsTr("Arc")],
+                    [0x2243, qsTr("Asymptotically Equal")],
+                    //[0xE100, qsTr("Boundary Line")],
+                    [0x2104, qsTr("Center Line")],
+                    [0x0394, qsTr("Delta")],
+                    [0x0278, qsTr("Electrical Phase")],
+                    //[0xE101, qsTr("Flow Line")],
+                    [0x2261, qsTr("Identity")],
+                    //[0xE200, qsTr("Initial Length")],
+                    //[0xE102, qsTr("Monument Line")],
+                    [0x00D7, qsTr("Multiplication")],
+                    [0x2260, qsTr("Not Equal")],
+                    [0x2126, qsTr("Ohm")],
+                    [0x03A9, qsTr("Omega")],
+                    [0x03C9, qsTr("omega")],
+                    [0x03A6, qsTr("Phi")],
+                    [0x0278, qsTr("phi")],
+                    [0x03C6, qsTr("Alt phi")],
+                    [0x03C0, qsTr("Pi")],
+                    [0x214A, qsTr("Property Line")],
+                    [0x2082, qsTr("Subscript 2")],
+                    [0x221A, qsTr("Square Root")],
+                    [0x25FB, qsTr("Square")],
+                    [0x00B2, qsTr("Squared")],
+                    [0x00B3, qsTr("Cubed")],
+                    ["\\SA^B;", qsTr("Stacked text"), "\\\\SA^B;"]
         ];
 
         if (dimension===true) {
@@ -1122,14 +1191,28 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
                 continue;
             }
 
-            var symbolSelf = symbol[0];
+            var symbolCode = symbol[0];
+            var symbolCodeStr;
+            var symbolSelf;
+            if (isNumber(symbolCode)) {
+                symbolCodeStr = symbolCode.toString(16);
+                while (symbolCodeStr.length<4) {
+                    symbolCodeStr = "0" + symbolCodeStr;
+                }
+                symbolCodeStr = ", \\U+" + symbolCodeStr;
+                symbolSelf = String.fromCharCode(symbolCode);
+            }
+            else {
+                symbolCodeStr = "";
+                symbolSelf = symbolCode;
+            }
             var symbolText = symbol[1];
-            var insertion = symbol[0];
+            var insertion = String.fromCharCode(symbol[0]);
             if (symbol.length===3) {
                 insertion = symbol[2];
             }
 
-            var action = subMenu.addAction(symbolSelf + "\t(" + symbolText + ")");
+            var action = subMenu.addAction(symbolSelf + "\t(" + symbolText + symbolCodeStr + ")");
             eval("action.triggered.connect(function() { lineEdit.setFocus(Qt.OtherFocusReason); lineEdit.insert(\"" + insertion + "\"); });");
         }
 
@@ -1170,19 +1253,40 @@ WidgetFactory.initTextBrowser = function(textBrowser, linkHandler, slot) {
 //    }
 //};
 
-WidgetFactory.initLayerCombo = function(comboBox, doc) {
+WidgetFactory.initLayerCombo = function(comboBox, doc, clear) {
+    var i;
+
     if (isNull(doc)) {
         return;
     }
+    if (isNull(clear)) {
+        clear = true;
+    }
+
+    var existingLayerNames = [];
+    if (clear) {
+        comboBox.clear();
+    }
+    else {
+        for (i=0; i<comboBox.count; i++) {
+            var t = comboBox.itemText(i);
+            existingLayerNames.push(t);
+        }
+    }
 
-    comboBox.clear();
     comboBox.iconSize = new QSize(16, 10);
     var names = doc.getLayerNames();
     //names = RS.sortAlphanumerical(names);
     names.sort(Array.alphaNumericalSorter);
-    for (var i=0; i<names.length; i++) {
+    for (i=0; i<names.length; i++) {
         var name = names[i];
         var layer = doc.queryLayer(name);
+
+        if (existingLayerNames.containsIgnoreCase(layer.getName())) {
+            // don't overwrite existing layers:
+            continue;
+        }
+
         var icon = RColor.getIcon(layer.getColor(), new QSize(comboBox.iconSize.width(),10));
         comboBox.addItem(icon, layer.getName());
     }
@@ -1243,6 +1347,88 @@ WidgetFactory.initVAlignCombo = function(comboBox) {
     comboBox.addItem(qsTr("Bottom"), RS.VAlignBottom);
 };
 
+WidgetFactory.initDimlunitCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Scientific"), RS.Scientific);
+    comboBox.addItem(qsTr("Decimal"), RS.Decimal);
+    comboBox.addItem(qsTr("Engineering"), RS.Engineering);
+    comboBox.addItem(qsTr("Architectural"), RS.ArchitecturalStacked);
+    comboBox.addItem(qsTr("Fractional"), RS.FractionalStacked);
+};
+
+WidgetFactory.initDimtadCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Centered"), 0);
+    comboBox.addItem(qsTr("Above"), 1);
+};
+
+WidgetFactory.initDimdsepCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(".", '.');
+    comboBox.addItem(",", ',');
+};
+
+WidgetFactory.initDimzinCombo = function(comboBox) {
+    comboBox.clear();
+    //comboBox.addItem(qsTr("Suppress 0'0\" (unsupported)"), 0);
+    comboBox.addItem(qsTr("Show trailing zeroes"), 0);
+    comboBox.addItem(qsTr("Include 0'0\"") + " " + qsTr("(unsupported)"), 1);
+    comboBox.addItem(qsTr("Include 0', suppress 0\"") + " " + qsTr("(unsupported)"), 2);
+    comboBox.addItem(qsTr("Include 0\", suppress 0'") + " " + qsTr("(unsupported)"), 3);
+    comboBox.addItem(qsTr("Suppress leading zeroes") + " " + qsTr("(unsupported)"), 4);
+    comboBox.addItem(qsTr("Suppress trailing zeroes"), 8);
+    comboBox.addItem(qsTr("Suppress leading / trailing zeroes") + " " + qsTr("(unsupported)"), 12);
+
+//    comboBox.addItem(qsTr("Suppress 0'0\""), 0);
+//    comboBox.addItem(qsTr("Include 0'0\""), 1);
+//    comboBox.addItem(qsTr("Include 0', suppress 0\""), 2);
+//    comboBox.addItem(qsTr("Include 0\", suppress 0'"), 3);
+};
+
+WidgetFactory.initDimdecCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem("0", 0);
+    comboBox.addItem("1", 1);
+    comboBox.addItem("2", 2);
+    comboBox.addItem("3", 3);
+    comboBox.addItem("4", 4);
+    comboBox.addItem("5", 5);
+    comboBox.addItem("6", 6);
+    comboBox.addItem("7", 7);
+    comboBox.addItem("8", 8);
+
+};
+WidgetFactory.initDimaunitCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Decimal Degrees"), RS.DegreesDecimal);
+    comboBox.addItem(qsTr("Deg/min/sec"), RS.DegreesMinutesSeconds);
+    comboBox.addItem(qsTr("Gradians"), RS.Gradians);
+    comboBox.addItem(qsTr("Radians"), RS.Radians);
+    comboBox.addItem(qsTr("Surveyor's units"), RS.Surveyors);
+};
+
+WidgetFactory.initDimazinCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Show trailing zeroes"), 0);
+    comboBox.addItem(qsTr("Suppress leading zeroes") + " " + qsTr("(unsupported)"), 1);
+    comboBox.addItem(qsTr("Suppress trailing zeroes"), 2);
+    comboBox.addItem(qsTr("Suppress leading / trailing zeroes") + " " + qsTr("(unsupported)"), 3);
+};
+
+WidgetFactory.initDimadecCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem("0", 0);
+    comboBox.addItem("1", 1);
+    comboBox.addItem("2", 2);
+    comboBox.addItem("3", 3);
+    comboBox.addItem("4", 4);
+    comboBox.addItem("5", 5);
+    comboBox.addItem("6", 6);
+    comboBox.addItem("7", 7);
+    comboBox.addItem("8", 8);
+};
+
+
 WidgetFactory.initOrientationCombo = function(comboBox) {
     comboBox.clear();
 
@@ -1287,7 +1473,9 @@ WidgetFactory.installComboBoxEventFilter = function(widget) {
             isOfType(c, RLineweightCombo) ||
             isOfType(c, RLinetypeCombo)) {
 
-            c.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
+            if (isFunction(c.installEventFilter)) {
+                c.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
+            }
             c.focusPolicy = Qt.ClickFocus;
             continue;
         }
